setwd("/Users/Kristian/Kristian/Dropbox/Studier/9. semester/Prosjektoppgave/Prosjektoppgave shared/Master Thesis/Model/Data/Raw Data")
plotDir <- "/Users/Kristian/Kristian/Dropbox/Studier/9. semester/Prosjektoppgave/Prosjektoppgave shared/Master Thesis/Model/Data/Plots"


library(fExtremes)
library(quantmod)

dataFrameAddress <- paste(getwd(), "/nqsalmon.csv", sep="")

df <- read.csv(dataFrameAddress, stringsAsFactors = FALSE)

dfPrices <- data.frame(as.Date(df[,3], format="%d/%m/%Y"), df[,5:11])
colnames(dfPrices)[1] <- "date"

### PARAMETRIZATION ###
minDate <- as.Date("2005-01-01")
maxDate <- as.Date(dfPrices[dim(dfPrices)[1],1])

rollVol_windowSize <- 13
cexAxis <- 1.75
cexAxisSmall <- 2.25
cexLab <- 1.75
cexLabSmall <- 2.25
cexLegend <- 1.75
cexMainLarge <- 1.5
cexMain <- 1.75
cexMainSmall <- 2.5
parMar <- c(5.1, 5.1, 4.1, 2.1) # par(mar=c(5.1,4.1,4.1,2.1) is default; bottom, left, top, right
parMarSmall <- c(7.1, 7.1, 4.1, 2.1)

plotToLatex <- TRUE
dropMain <- TRUE

### EXTRACTION OF SERIES ###
dfPrices <- dfPrices[dfPrices[,1] >= minDate,]
dfPrices <- dfPrices[dfPrices[,1] <= maxDate,]

### BEGIN SCRIPT ###

# Plot the price series
N <- dim(dfPrices)[2]
dates <- dfPrices[,1]
xlim <- c(min(dates), max(dates))
ylim <- c(min(dfPrices[,2:N]), 1.1*max(dfPrices[,2:N]))
ltys <- seq(2:6)+1

plotDf <- data.frame(dfPrices[,1:2], apply(dfPrices[,2:N], 1, min), 
                     apply(dfPrices[,2:N], 1, max))
for (j in 2:dim(plotDf)[2]) {
  for (i in 2:dim(plotDf)[1]) {
    if (plotDf[i,j] == 0) {
      plotDf[i,j] = plotDf[i-1,j]
    }
  }
}

# First plot the price series
pdf(paste(plotDir, "/nqsalmon-weekly-price-range", ".pdf", sep=""), height=8,
    width=14, family = "Palatino")
par(cex.lab=cexLab, cex.axis=cexAxis, cex.main=cexMain, mar=parMar)
plot(plotDf[,2] ~ plotDf[,1], type="l", lty=1, xlim=xlim, ylim=ylim,
     col="red", lwd=0.5, xlab="Time", ylab="USD/kg", main="", xaxt="n", 
     yaxt="n", bty="n")
lines(plotDf[,1], plotDf[,3], col='grey30', xlim=xlim, ylim=ylim)
lines(plotDf[,1], plotDf[,4], col='grey30', xlim=xlim, ylim=ylim)
polygon(c(plotDf[,1], rev(plotDf[,1])), c(plotDf[,4], rev(plotDf[,3])),
        col='grey', border=NA)
par(new=T)
plot(plotDf[,2] ~ plotDf[,1], type="l", lty=1, xlim=xlim, ylim=ylim,
     col="red", lwd=1, xlab="Time", ylab="USD/kg", xaxt="n", yaxt="n", bty="n",
     main="Weekly NASDAQ Salmon Index (NQSALMON) with weight class price range")
dateAxt <- seq(min(dates), max(dates), by="year")
axis(side=1, at=dateAxt, labels=format(dateAxt, '%b-%Y'))
priceAxt <- seq(1,round(max(dfPrices[,2:N]))+1, 1)
axis(side=2, at=priceAxt, labels=format(priceAxt, nsmall=1))
legend('topleft', fill=c('red', 'grey'), legend=c('NASDAQ Salmon Index', 'Price range across weight classes'),
       cex=cexLegend, bty="n")
dev.off()

### Then plot weekly log returns
T_max <- dim(dfPrices)[1]
dates_logRets <- as.Date(dates[2:T_max])
dfLogRets <- data.frame(date=dates_logRets, 
               logReturns=log(dfPrices[2:T_max,2]) - log(dfPrices[1:(T_max-1),2]))

setwd('/Users/Kristian/Kristian/Dropbox/Studier/9. semester/Prosjektoppgave/Prosjektoppgave shared/Master Thesis/Model/Data/SalmonAnalysis')
plotDir <- paste(getwd(), "/plots/data-analysis", sep="")

dfLogRets <- importGroupStructureDataFrame(paste(getwd(), '/modeloutput/', 'df_full.csv', sep=''), constraints=T)

startDate_descStats <- as.Date("2007-08-31")
endDate_descStats   <- as.Date("2017-01-31")
dfLogRets <- importDataFrame(dataFrameAddress=dataFrameAddress, 
                                  startDate=as.Date('2005-01-01'), endDate=as.Date('2017-01-31'),
                                  convertToReturns='log')[,1:2]
dfLogRets <- dfLogRets[which(dfLogRets[,1] >= startDate_descStats & dfLogRets[,1] <= endDate_descStats),]

dates_logRets <- as.Date(dfLogRets[,1])

col1 <- "black"
col2 <- "#800000"
col3 <- "#000080"



## 1) Time series
pdf(paste(plotDir, "/nqsalmon-log-returns-monthly", ".pdf", sep=""), height=8,
    width=14, family = "Palatino")
par(cex.lab=cexLabSmall*1.1, cex.axis=cexAxisSmall*1.1, cex.main=cexMainSmall, mar=parMar)
xlim_logRets <- c(dates_logRets[1], dates_logRets[length(dates_logRets)])
ylim_logRets <- c(1.1*min(dfLogRets[,2]), 1.1*max(dfLogRets[,2]))
dateAxt_logRets <- seq(dates_logRets[1], dates_logRets[length(dates_logRets)], by="year")
mainString <- if(dropMain) "" else "NASDAQ Salmon Index (NQSALMON) monthly log returns"
plot(dfLogRets[,2] ~ dates_logRets, type="l", lty=1, xlim=xlim_logRets,
     ylim=ylim_logRets, xlab='Time', ylab='Log return', bty='n', xaxt='n',
     main=mainString)
axis(side=1, at=dateAxt_logRets, labels=format(dateAxt_logRets, '%Y'))
dev.off()

## 2) Squared log returns
dfSqLogRets <- data.frame(date=dates_logRets, dfLogRets[,2]^2)
pdf(paste(plotDir, "/nqsalmon-sq-log-returns-monthly", ".pdf", sep=""),
    height=8, width=14, family = "Palatino")
par(cex.lab=cexLabSmall*1.1, cex.axis=cexAxisSmall*1.1, cex.main=cexMainSmall, mar=parMar)
xlim_logRets <- c(min(dfSqLogRets[,1]), max(dfSqLogRets[,1]))
ylim_logRets <- c(1.1*min(dfSqLogRets[,2]), 1.1*max(dfSqLogRets[,2]))
dateAxt_logRets <- seq(dates_logRets[1], dates_logRets[length(dates_logRets)], by="year")
mainString <- if(dropMain) "" else "NASDAQ Salmon Index (NQSALMON) squared monthly log returns"
plot(dfSqLogRets[,2] ~ dates_logRets, type="l", lty=1, xlim=xlim_logRets,
     ylim=ylim_logRets, xlab='Time', ylab='Squared log return', bty='n', xaxt='n',
     main=mainString)
axis(side=1, at=dateAxt_logRets, labels=format(dateAxt_logRets, '%Y'))
dev.off()

## 3) Histogram of log returns
pdf(paste(plotDir, "/nqsalmon-log-returns-monthly-histogram", ".pdf", sep=""), height=8,
    width=10, family = "Palatino")
par(cex.lab=cexLab, cex.axis=cexAxis, cex.main=cexMainLarge, mar=parMar)
mainString <- if(dropMain) "" else paste("Histogram of NASDAQ Salmon Index (NQSALMON) monthly log returns",
                                         sep = "")
hist(dfLogRets[,2], mainString, xlab="Log return", ylab="Rel. frequency [%]", 
     freq=FALSE, breaks=18, main=mainString, density=15)
sprintf("%4.2e", mean(dfLogRets[,2]))
mu_string <- sprintf("%4.2e", mean(dfLogRets[,2]))
sd_string <- sprintf("%4.2e", sd(dfLogRets[,2]))
# legend(
#        legend=c(bquote())
#        legend=c(as.expression(bquote(paste(mu, "=", .(paste("", mu_string, sep=""))))), as.expression(bquote(paste(sigma, "=", .(paste("", sd_string, sep=""))))),
#                 as.expression(bquote("Fitted Gaussian"))))
curve(dnorm(x, mean = mean(dfLogRets[,2]), sd = sd(dfLogRets[,2])), add=TRUE, col = col2, lty = 2, lwd = 2) # Gaussian overlay

legend('topright', cex=cexLegend, lty=c(0,0,2), lwd=c(0,0,2), col=c('white', 'white', col2),
       legend=do.call('expression', list(bquote(mu == .(mu_string)),
                                                        bquote(sigma == .(sd_string)),
                                                        bquote('Fitted Gaussian'))), 
       bg='white')

dev.off()

## 4) Normal Q-Q Plot of log returns
pdf(paste(plotDir, "/nqsalmon-log-returns-monthly-normal-q-q", ".pdf", sep=""),
    height=8, width=10, family = "Palatino")
par(cex.lab=cexLabSmall, cex.axis=cexAxisSmall, cex.main=cexMain, mar = c(5,5,4,4))
qqnorm(dfLogRets[,2], main = "",
       plot.it = TRUE, datax = FALSE, bty="n", lwd=1, cex=1.5)
qqline(dfLogRets[,2], datax = FALSE, distribution = qnorm,
       probs = c(0.25, 0.75), qtype = 7, col = col2, lwd=2.5, lty=2)
# grid(nx = NULL, ny = NULL, col = 'gray', lty = 'dotted',
#      lwd = 1, equilogs = TRUE)
dev.off()

## 5) Autocorrelation in log returns
pdf(paste(plotDir, "/nqsalmon-autocorr-log-return-monthly", ".pdf", sep=""),
    height=8, width=10, family = "Palatino")
par(cex.lab=cexLabSmall, cex.axis=cexAxisSmall, cex.main=cexMainSmall, mar=parMar)
mainString <- if(dropMain) "" else "Autocorrelation function for monthly log returns"
acf(dfLogRets[,2], lag.max=52, type="correlation", plot=T,
    main=mainString, bty="n", ci.col=col2)
axis(side=1)
dev.off()




## 2) Realized volatility
dfRollVol <- data.frame(date=dates_logRets,
              rollVol=apply(data.frame(dfLogRets[,2]), 2, runSD, n=rollVol_windowSize)*sqrt(52))
dfRollVol <- na.omit(dfRollVol)
pdf(paste(plotDir, "/nqsalmon-log-returns-weekly-volatility_window=", rollVol_windowSize, ".pdf", sep=""),
    height=8, width=14, family = "Palatino")
par(cex.lab=cexLab, cex.axis=cexAxis, cex.main=cexMain, mar=parMar)
ylim_rollVol <- c(0.95*min(dfRollVol[,2]), 1.1*max(dfRollVol[,2]))
plot(dfRollVol[,2] ~ dfRollVol[,1], type="l", lty=1, xlim=xlim_logRets,
     ylim=ylim_rollVol, xlab='Time', ylab='Annualized volatility', bty='n', xaxt='n',
     main=bquote(bold("NASDAQ Salmon Index (NQSALMON) annualized log return volatility, window size =") ~ .(rollVol_windowSize) ~ bold("weeks")))
axis(side=1, at=dateAxt_logRets, labels=format(dateAxt_logRets, '%Y'))
dev.off()






## 6) Squared absolute returns
dfAbsLogRets <- data.frame(date=dates_logRets, abs(dfLogRets[,2]))
pdf(paste(plotDir, "/nqsalmon-abs-log-returns-weekly", ".pdf", sep=""),
    height=8, width=14, family = "Palatino")
par(cex.lab=cexLab, cex.axis=cexAxis, cex.main=cexMain, mar=parMar)
xlim_logRets <- c(min(dfAbsLogRets[,1]), max(dfAbsLogRets[,1]))
ylim_logRets <- c(1.1*min(dfAbsLogRets[,2]), 1.1*max(dfAbsLogRets[,2]))
dateAxt_logRets <- seq(min(dfAbsLogRets[,1]), max(dfAbsLogRets[,1]), by="year")
plot(dfAbsLogRets[,2] ~ dates_logRets, type="l", lty=1, xlim=xlim_logRets,
     ylim=ylim_logRets, xlab='Time', ylab='Absolute log return', bty='n', xaxt='n',
     main="NASDAQ Salmon Index (NQSALMON) absolute weekly log returns")
axis(side=1, at=dateAxt_logRets, labels=format(dateAxt_logRets, '%Y'))
dev.off()



pdf(paste(plotDir, "/nqsalmon-autocorr-sq-log-return-weekly", ".pdf", sep=""),
    height=8, width=10, family = "Palatino")
par(cex.lab=cexLabSmall, cex.axis=cexAxisSmall, cex.main=cexMainSmall, mar=parMar)
acf(dfSqLogRets[,2], lag.max=52, type="correlation", plot=T,
    main="Autocorrelation function for squared weekly log returns", bty="n")
axis(side=1)
dev.off()

pdf(paste(plotDir, "/nqsalmon-autocorr-abs-log-return-weekly", ".pdf", sep=""),
    height=8, width=10, family = "Palatino")
par(cex.lab=cexLabSmall, cex.axis=cexAxisSmall, cex.main=cexMainSmall, mar=parMar)
acf(dfAbsLogRets[,2], lag.max=52, type="correlation", plot=T,
    main="Autocorrelation function for absolute weekly log returns", bty="n")
axis(side=1)
dev.off()

## 8) Log return vs. delta vol.
dates_logRetDeltaVol <- dfRollVol[2:dim(dfRollVol)[1],1]
n_logRetDeltaVol <- length(dates_logRetDeltaVol)

dfLogRetDeltaVol <- data.frame(date=dates_logRetDeltaVol,
                    dfLogRets[(dim(dfLogRets)[1] - n_logRetDeltaVol+1):dim(dfLogRets)[1],2],
                    dfRollVol[2:dim(dfRollVol)[1],2] - dfRollVol[1:(dim(dfRollVol)[1]-1),2],
                    dfRollVol[2:dim(dfRollVol)[1],2])
pdf(paste(plotDir, "/nqsalmon-log-ret-vs-delta-vol", ".pdf", sep=""),
    height=8, width=10, family = "Palatino")
par(cex.lab=cexLab, cex.axis=cexAxis, cex.main=cexMain, mar=parMar)
plot(dfLogRetDeltaVol[,3] ~ dfLogRetDeltaVol[,2], type="p", lty=1, 
     xlab='Log return', ylab='Change in volatility', bty='n',
     main=bquote(atop(bold("NASDAQ Salmon Index (NQSALMON) log returns vs. changes in volatility"),
                      "Rolling vol. window size:" ~ .(rollVol_windowSize) ~ "weeks")))
dev.off()

## 9) Log return vs. vol.
pdf(paste(plotDir, "/nqsalmon-log-ret-vs-vol", ".pdf", sep=""),
    height=8, width=10, family = "Palatino")
par(cex.lab=cexLab, cex.axis=cexAxis, cex.main=cexMain, mar=parMar)
plot(dfLogRetDeltaVol[,4] ~ dfLogRetDeltaVol[,2], type="p", lty=1, 
     xlab='Log return', ylab='Volatility', bty='n',
     main=bquote(atop(bold("NASDAQ Salmon Index (NQSALMON) log returns vs. volatility"),
                      "Rolling vol. window size:" ~ .(rollVol_windowSize) ~ "weeks")))
dev.off()

## 10) Mean excess log return
pdf(paste(plotDir, "/nqsalmon-mean-excess-log-return-plot", ".pdf", sep=""),
    height=8, width=14, family = "Palatino")
par(cex.lab=cexLabSmall, cex.axis=cexAxisSmall*1.1, cex.main=cexMainSmall, mar=parMarSmall)
mePlot(dfLogRets[,2], doplot=T, labels=F, bty="n", type="l", xlab="", ylab="")
mainString <- if(dropMain) "" else "Mean excess plot of weekly NQSALMON log returns"
title(xlab="Threshold", ylab="Mean excess return",
      main=mainString, cex.lab=cexLabSmall*1.3)
dev.off()

pdf(paste(plotDir, "/nqsalmon-mean-excess-log-loss-plot", ".pdf", sep=""),
    height=8, width=14, family = "Palatino")
par(cex.lab=cexLabSmall, cex.axis=cexAxisSmall*1.1, cex.main=cexMainSmall, mar=parMarSmall)
mePlot(-dfLogRets[,2], doplot=T, labels=F, bty="n", type="l", xlab="", ylab="")
mainString <- if(dropMain) "" else "Mean excess plot of weekly NQSALMON log losses"
title(xlab="Threshold", ylab="Mean excess loss", 
      main=mainString, cex.lab=cexLabSmall*1.3)
dev.off()



































































































